@@ -46,6 +46,8 @@ class AurfluxCog:
         pass
 
     def register(self, cog_member: ty.Union[Command, ty.Tuple[EventMuxer, ty.Union[EventFunction, EventRouter, EventWaiter]]]):
+        print(f"Cog registering!")
+        print(cog_member)
         if isinstance(cog_member, Command):
             self.commands.add(cog_member)
         else:
@@ -61,6 +63,7 @@ class AurfluxCog:
                 muxer.remove_listener(listener)
         for command in self.commands:
             del self.aurflux.commands[command.name]
+        self.router.detatch()
 
     @abc.abstractmethod
     def route(self):
@@ -103,7 +106,7 @@ def register_builtins(aurflux: Aurflux):
         try:
             if cmd not in aurflux.commands:
                 return
-            async for response in __aiterify(aurflux.commands[cmd].execute(ctx)):
+            async for response in __aiterify(await aurflux.commands[cmd].execute(ctx)):
                 await response.execute(ctx)
         except CommandError as e:
             info_message = f"{e}"
@@ -126,8 +129,10 @@ def register_builtins(aurflux: Aurflux):
                 cog.teardown()
                 module = importlib.reload(inspect.getmodule(cog))
                 new_cog = getattr(module, cog.__class__.__name__)(ctx.aurflux)
+                await new_cog.startup()
             reloaded_cogs.append(new_cog)
         ctx.aurflux.cogs = reloaded_cogs
+        return Response()
 
     @CommandCheck.check(lambda ctx: ctx.author.id == aurflux.admin_id)
     @aurflux.commandeer(name="exec", parsed=False, private=True)
@@ -142,6 +147,7 @@ def register_builtins(aurflux: Aurflux):
                 res = await exec_func(script, globals(), locals())
             except Exception as e:
                 res = re.sub(r'File ".*[\\/]([^\\/]+.py)"', r'File "\1"', traceback.format_exc(limit=1))
+
         return Response((f""
                          f"Ran in {t.elapsed * 1000:.2f} ms\n"
                          f"**IN**:\n"
@@ -181,13 +187,14 @@ def register_builtins(aurflux: Aurflux):
 class Aurflux(discord.Client):
     CONFIG: Config
 
-    def __init__(self, name, admin_id: int, parent_router: EventRouter = None, *args, **kwargs):
+    def __init__(self, name, admin_id: int, parent_router: EventRouter = None, secondary=False, *args, **kwargs):
         super(Aurflux, self).__init__(*args, **kwargs)
         self.CONFIG = Config(name)
         self.commands: ty.Dict[str, Command] = {}
         self.router = EventRouter(name="aurflux", parent=parent_router)
         self.admin_id = admin_id
-        register_builtins(self)
+        if not secondary:
+            register_builtins(self)
         self.cogs: ty.List[AurfluxCog] = []
         self.aiohttp_session = aiohttp.ClientSession()
 
